﻿/*
  Antenna House PDF Tool API V7.0
  .Net Interface sample program

  概要：JavaScriptの削除

  Copyright (C) 2023- Antenna House, Inc. All rights reserved.
  Antenna House is a trademark of [Antenna House, Inc.]

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

using PdfTkNet;
using System;

namespace OptimizeRemoveJavaScripts
{
    internal class OptimizeRemoveJavaScripts
    {
        // そのクラスのusageを表示する関数
        private static void printUsage()
        {
            Console.WriteLine("usage: OptimizeRemoveJavaScripts in-pdf-file out-pdf-file");
        }

        static void Main(string[] args)
        {
            if (args.Length < 2)
            {
                printUsage();
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    optimizeDocByRemovesetJavaScripts(doc);

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                Console.WriteLine(ex.StackTrace);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

        public static void optimizeDocByRemovesetJavaScripts(PtlPDFDocument doc)
        {
            try
            {
                using (PtlParamOptimize paramOptimize = new PtlParamOptimize())
                {
                    //オープンアクションの削除フラグを設定
                    paramOptimize.setRemoveJavaScripts(true);

                    // 最適化の実行
                    doc.optimize(paramOptimize);
                }
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }
    }
}
